@@ -20,11 +20,9 @@
 
 #include <gio/gio.h>
 
+#include "extension-common.h"
 #include "font-manager-menu-provider.h"
 
-#define FONT_VIEWER_BUS_ID "org.gnome.FontViewer"
-#define FONT_VIEWER_BUS_PATH "/org/gnome/FontViewer"
-
 struct _FontManagerMenuProvider
 {
     GObject parent_instance;
