@@ -18,15 +18,12 @@
  * If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.
 */
 
-#ifndef __FONT_MANAGER_PROGRESS_DATA_H__
-#define __FONT_MANAGER_PROGRESS_DATA_H__
+#pragma once
 
 #include <stdio.h>
 #include <glib.h>
 #include <glib-object.h>
 
-G_BEGIN_DECLS
-
 #define FONT_MANAGER_TYPE_PROGRESS_DATA (font_manager_progress_data_get_type())
 G_DECLARE_FINAL_TYPE(FontManagerProgressData, font_manager_progress_data, FONT_MANAGER, PROGRESS_DATA, GObject)
 
@@ -35,7 +32,3 @@ typedef gboolean (*FontManagerProgressCallback) (FontManagerProgressData *data);
 FontManagerProgressData * font_manager_progress_data_new (const gchar *message, guint processed, guint total);
 gboolean font_manager_progress_data_print (FontManagerProgressData *self);
 
-G_END_DECLS
-
-#endif /* __FONT_MANAGER_PROGRESS_DATA_H__ */
-
